package de.intevation.flys.artifacts.model;

import org.apache.log4j.Logger;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;

import de.intevation.flys.artifacts.ManualPointsArtifact;

import de.intevation.artifactdatabase.state.DefaultFacet;
import de.intevation.artifactdatabase.state.Facet;


/**
 * Facet to access ManualPoints that where added by user.
 */
public class ManualPointsFacet
extends      DefaultFacet
{
    /** Logger for this class. */
    private static final Logger logger = Logger.getLogger(ManualPointsFacet.class);


    /**
     * Trivial Constructor.
     */
    public ManualPointsFacet() {
    }


    /**
     * Trivial Constructor for a ManualPointsFacet.
     *
     * @param index       Database-Index to use.
     * @param name        Name (~type) of Facet.
     * @param description Description of Facet.
     */
    public ManualPointsFacet(int index, String name, String description) {
        super(index, name, description);
    }


    /**
     * Get List of ManualPointss for river from Artifact.
     *
     * @param artifact (ManualPoints-)Artifact to query for list of ManualPoints.
     * @param context  Ignored.
     */
    @Override
    public Object getData(Artifact artifact, CallContext context) {
        ManualPointsArtifact pointsArtifact = (ManualPointsArtifact) artifact;
        return pointsArtifact.getPointsData();
    }


    /** Do a deep copy. */
    @Override
    public Facet deepCopy() {
        ManualPointsFacet copy = new ManualPointsFacet();
        copy.set(this);
        return copy;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
